@@ -11,7 +11,7 @@ import numpy as np
 import torch
 import numpy
 import scipy
-from scipy.stats import norm, median_abs_deviation
+from scipy.stats import norm
 from scipy.integrate import quad
 import matplotlib.pyplot as plt
 
