@@ -12,7 +12,7 @@ import pandas as pd
 import pickle5 as pickle
 from scipy import interpolate
 
-def get_convergence(search_dir,with_surrogate=False,werr=True,niters=None,nruns=None,debug=False,**kwargs):
+def get_convergence(search_dir,with_surrogate=False,werr=True,niters=None,nruns=None,debug=False,median=False,**kwargs):
     dir_list = sorted(glob.glob(search_dir+'/*'))
     if any('.log' in dir_name for dir_name in dir_list):
         dir_list = [search_dir]
@@ -50,7 +50,10 @@ def get_convergence(search_dir,with_surrogate=False,werr=True,niters=None,nruns=
         all_results[0][i] = all_results[0][i][:niters]
         all_results[1][i] = all_results[1][i][:niters]
     all_results = numpy.array(all_results)
-    mean_loss = numpy.mean(all_results[0],axis=0)
+    if median:
+        mean_loss = numpy.median(all_results[0],axis=0)
+    else:
+        mean_loss = numpy.mean(all_results[0],axis=0)
     if werr:
         mean_sdev = numpy.sqrt(numpy.sum(all_results[1]**2,axis=0))/all_results[0].shape[0]
     else:
