@@ -177,7 +177,7 @@ def hpo_sensitivity(results,ms=20,edgewidth=2,ncols=3,config=None,log=False):
                 ),
             ),row=irow, col=jcol)
         fig['layout']['xaxis%i' % (n+1)]['title'] = hp_names[n]
-        if n%3==0:
+        if n%ncols==0:
             fig['layout']['yaxis%i' % (n+1)]['title'] = 'Loss'
     if log:
         fig.update_yaxes(type='log')
@@ -189,6 +189,32 @@ def hpo_sensitivity(results,ms=20,edgewidth=2,ncols=3,config=None,log=False):
     fig.write_html('sensitivity.html')
     fig.show()
 
+def plot_sensitivity(results,ms=20,edgewidth=0.1,ncols=3,config=None,log=False,save=True,show=False,**kwargs):
+    text_coord, custom_data, hp_names = get_custom_data(results,config,sensitivity=True)
+    n_hps = custom_data.shape[1]-3
+    nrows = int(numpy.ceil(n_hps/ncols))
+    plt.style.use('seaborn')
+    fig,ax = plt.subplots(nrows,ncols,figsize=(ncols*3+1,3*nrows),dpi=200,sharey=True)
+    # ax = ax.flatten
+    plt.subplots_adjust(top=0.97,wspace=0.07,hspace=0.3,right=0.9,left=0.07,bottom=0.08)
+    for n,(irow,jcol) in enumerate([(i,j) for i in range(nrows) for j in range(ncols)]):
+        if n+1>n_hps:
+            break
+        im = ax[irow][jcol].scatter(custom_data[:,3+n],results.loss,c=results.stdev,lw=edgewidth,ec='black',alpha=0.5,s=ms,cmap='plasma')
+        if n%ncols==0:
+            ax[irow][jcol].set_ylabel('Loss')
+        ax[irow][jcol].set_xlabel(hp_names[n])
+    cax = plt.axes([0.92, 0.08, 0.02, 0.89])
+    cbar = plt.colorbar(im,cax=cax)
+    cbar.set_alpha(1)
+    cbar.draw_all()
+    cbar.set_label(r'1-$\mathrm{\sigma}$ Deviation')
+    cbar.ax.xaxis.set_ticks_position('top')
+    cbar.ax.xaxis.set_label_position('top')
+    if save: plt.savefig('figure.pdf')
+    if show: plt.show()
+    plt.close()
+    
 def model_visualization_1d(X,Y,path,evaluation,surrogate,imax=10,sigma=False,ylim=[-0.5,2.5]):
     scaler = round(1/(X[1]-X[0]))
     os.makedirs('%s/plots' % (path),exist_ok=True)
